California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
ANGELIDES, PHIL CAMEJO, PETER MIGUEL JORDAN, JANICE NOONAN, EDWARD C. OLIVIER, ARTHUR C. SCHWARZENEGGER, ARNOLD
| LIEUTENANT GOVERNOR
ALEXANDER, STEWART A. GARAMENDI, JOHN MC CLINTOCK, THOMAS SHAW, LYNNETTE M. WARREN, DONNA J.
SECRETARY OF STATE
AKIN, MARGIE BOWEN, DEBRA HILL, FORREST LIGHTFOOT, GAIL K. MC MILLON, GLENN L. MC PHERSON, BRUCE
| CONTROLLER
BARRON, ELIZABETH C. CAMPBELL, WARREN MARK CHIANG, JOHN STRICKLAND, TONY TELLO, DONNA WELLS, LAURA
TREASURER
LOCKYER, BILL NOONAN, JUSTIN E. PARRISH, CLAUDE SANDERS, GERALD SMITHSON, MARIAN V. THAKKER, MEHUL
| ATTORNEY GENERAL
BROWN, EDMUND G. (JERRY) HARRISON, JACK L. POOCHIGIAN, CHUCK WEISSMAN, KENNETH A. WYMAN, MICHAEL S.
SUPERINTENDENT OF PUBLIC INSTRUCTION
O'CONNELL, JACK
| INSURANCE COMMISSIONER
BURDEN, JAY EARL BUSTAMANTE, CRUZ M. CAFIERO, LAWRENCE CONDIT, TOM OGDEN, DALE F. POIZNER, STEVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
CAMPBELL, DAVID NEIGHBORS, DAVID J. WATSON, KENNITA L. YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
LEONARD, BILL MICHLIN, WILLARD D. PERRY, RICHARD R. RABOY, TIM
MEMBER BOARD OF EQUALIZATION 03
CHRISTIAN-HEISING, MARY FINLEY, MARY LOU STEEL, MICHELLE
| MEMBER BOARD OF EQUALIZATION 04
CHU, JUDY FORSCH, GLEN R. HENDERSON, CINDY VARELA KADERA, MONICA W.
SENATE DISTRICTS
STATE SENATE 02
WIESNER, LAWRENCE R. WIGGINS, PATRICIA ANN
| STATE SENATE 04
AANESTAD, SAMUEL M. MUNROE, TONY SINGH, PAUL R. VIZZARD, ROBERT WELLS
STATE SENATE 06
GARBEROGLIO, ALANA N. GREEN JR., PAUL ROBINSON STEINBERG, DARRELL WEBER, C.T.
| STATE SENATE 08
SKIPAKEVICH, MICHAEL YEE, LELAND Y.
STATE SENATE 10
CORBETT, ELLEN FILIPOVICH, LOU
| STATE SENATE 12
DENHAM, JEFF NICKEL III, GEORGE W.
STATE SENATE 14
COGDILL, DAVID E. FIRCH, WESLEY W.
| STATE SENATE 16
FLOREZ, DEAN
STATE SENATE 18
ASHBURN, ROY DAVIS, FRED B. RICK, MATTHEW
| STATE SENATE 20
BROWN, PAMELA J. PADILLA, ALEX
STATE SENATE 22
CEDILLO, GILBERT LEVY, MURRAY TEN, MIKE
| STATE SENATE 24
CARVER, ROBERT W. ROMERO, GLORIA
STATE SENATE 26
RAYMOND, BUD F. RIDLEY-THOMAS, MARK
| STATE SENATE 28
DE BAETS, PETER D. LIDDLE, CHERRYL OROPEZA, JENNY
STATE SENATE 30
CALDERON, RONALD MINERD, SELMA
| STATE SENATE 32
MC LEOD, GLORIA NEGRETE
STATE SENATE 34
CORREA, LOU DAUCHER, LYNN
| STATE SENATE 36
HANSON, MARK N. HOLLINGSWORTH, DENNIS SHEA, JOE B.
STATE SENATE 38
KLEA, BRIAN A. WYLAND, MARK B.
| STATE SENATE 40
DUCHENY, DENISE MORENO THOMAS, JESSE WALDEN, DAVID K.
ASSEMBLY DISTRICTS
ASSEMBLY 01
BERG, PATTY REED, THOMAS T. TYRONE, RAY
| ASSEMBLY 02
DYNAN, PHILIP E. LA MALFA, DOUG SMITH, MEL
ASSEMBLY 03
HARRINGTON, MICHAEL "MICKEY" KEENE, RICHARD J.
| ASSEMBLY 04
FRITTS, GERALD M. GAINES, EDWARD T HASWELL, ROB MURPHY, MICHAEL PATRICK
ASSEMBLY 05
BELL, BRANDON R. LOPEZ, MICHAEL NIELLO, ROGER
| ASSEMBLY 06
HARTNETT, MICHAEL HUFFMAN, JARED OLMSTEAD, RICHARD WOODS, CAT
ASSEMBLY 07
EVANS, NOREEN M.
| ASSEMBLY 08
GOULD, JOHN S. WOLK, LOIS
ASSEMBLY 09
CHAN, WILLIAM JONES, DAVE
| ASSEMBLY 10
BONSER, JANICE M. COOK, COLONEL JIM A. NAKANISHI, ALAN S. TROYER, ALBERT
ASSEMBLY 11
DE SAULNIER, MARK NOTT, CORY M. SIMONSEN, ARNE
| ASSEMBLY 12
EPSTEIN, HOWARD HERMANSON, BARRY MA, FIONA
ASSEMBLY 13
LENO, MARK MALDONADO JR., RAMIRO
| ASSEMBLY 14
HANCOCK, LONI WOLF, LEIGH N.
ASSEMBLY 15
COLEMAN, TERRY HOUSTON, GUY
| ASSEMBLY 16
SWANSON, SANDRE YTUARTE, EDWARD
ASSEMBLY 17
GALGIANI, CATHLEEN MACHADO, GERARD J.
| ASSEMBLY 18
BUCK, JILL ANN HAYASHI, MARY
ASSEMBLY 19
GUFLER, ELSIE MULLIN, GENE R.
| ASSEMBLY 20
NISHIMURA, KEN A. TORRICO, ALBERTO
ASSEMBLY 21
KIRALY, VIRGINIA C. RUSKIN, IRA
| ASSEMBLY 22
LIEBER, SALLY RIFFENBURGH, ROGER RALPH
ASSEMBLY 23
COTO, JOE PATROSSO, MARK
| ASSEMBLY 24
BEALL, JIM HILEMAN, LAWRENCE R. SILVA, LIONEL H.
ASSEMBLY 25
BERRYHILL, TOM BUFFORD, JAMES LEX DELL'ORTO, MICHAEL RAY
| ASSEMBLY 26
AGHAZARIAN, GREG GOEKEN, KENNETH J.
ASSEMBLY 27
LAIRD, JOHN S. MORRISON, COLIN M.
| ASSEMBLY 28
CABALLERO, ANNA VELAZQUEZ, IGNACIO
ASSEMBLY 29
CROCKFORD, JOHN VILLINES, MICHAEL N. ZWICKEL, JONATHAN IRA
| ASSEMBLY 30
GILMORE, DANNY D. PARRA, NICOLE
ASSEMBLY 31
ARAMBULA, JUAN
| ASSEMBLY 32
FULLER, JEAN VEGA, MARIBEL
ASSEMBLY 33
BLAKESLEE, SAM CUTHBERT, ROBERT
| ASSEMBLY 34
FARRELLY, DESMOND MAZE, BILL SILVA, DAVID MINTON
ASSEMBLY 35
MARTIN, CRISTINA CARRENO NAVA, PEDRO I.
| ASSEMBLY 36
BYNUM, ROBERT "BO" RUNNER, SHARON
ASSEMBLY 37
MASRY, FERIAL STRICKLAND, AUDRA
| ASSEMBLY 38
CHRISTENSEN, PEGGY L. SHAW, LYN SMYTH, CAMERON
ASSEMBLY 39
ALARCON, RICHARD
| ASSEMBLY 40
LEVINE, LLOYD MONTAINE, RICHARD E.
ASSEMBLY 41
BROWNLEY, JULIA DOLZ, TONY FRANKOWSKI, CONRAD S.
| ASSEMBLY 42
FEUER, MICHAEL NELSON GOLDMAN, COLIN S. SION, STEVEN MARK
ASSEMBLY 43
AGBABA, MICHAEL M. KREKORIAN, PAUL MYERS, STEVEN A.
| ASSEMBLY 44
CARWILE, SCOTT COSTA, RICARDO M. PORTANTINO, ANTHONY YANAGA, BARRON T.
ASSEMBLY 45
ALLEN-NEWMAN, SAMANTHA DE LEON, KEVIN
| ASSEMBLY 46
NUNEZ, FABIAN
ASSEMBLY 47
BASS, KAREN DODGE, JEFFERS MAC ARTHUR
| ASSEMBLY 48
DAVIS, MIKE GREEN, BRENDA CAROL
ASSEMBLY 49
BROWN, LAURA G. ENG, MICHAEL SIEGRIST, ESTHELA G.
| ASSEMBLY 50
DE LA TORRE, HECTOR MILLER, GLADYS O.
ASSEMBLY 51
MOEN, ROSS PRICE, CURREN D. SWINNEY, CARL M. "MARTY"
| ASSEMBLY 52
DYMALLY, MERVYN M.
ASSEMBLY 53
ABRAMS, KARL FORD, MARY JO LIEU, TED THOTTAM, PETER L.
| ASSEMBLY 54
JACKSON, MICHAEL A. KARNETTE, BETTY
ASSEMBLY 55
RICHARDSON, LAURA UNDERHILL, MARGHERITA
| ASSEMBLY 56
HU, GRACE MENDOZA, TONY
ASSEMBLY 57
CARVER, HOLLY E. HERNANDEZ, EDWARD P.
| ASSEMBLY 58
CALDERON, CHARLES M. KLEINPELL, JIM
ASSEMBLY 59
ADAMS, ANTHONY BARKAN, ELLIOTT ROBERT STONE, JILL K.
| ASSEMBLY 60
HUFF, ROBERT 'BOB' TAMOM, VANNARITH THOMAS
ASSEMBLY 61
LOPEZ, BENJAMIN I. SOTO, NELL
| ASSEMBLY 62
CARTER, WILMER AMINA MENDOZA-WARE, MARGE
ASSEMBLY 63
EMMERSON, BILL WESTWOOD, MARK DAVID
| ASSEMBLY 64
BENOIT, JOHN J. RASSO, PAUL M.
ASSEMBLY 65
COOK, PAUL J. RAMIREZ-DEAN, RITA TALEB, JON
| ASSEMBLY 66
JEFFRIES, KEVIN D. NICHOLSON, LAUREL A.
ASSEMBLY 67
ROBERTS, RAYMOND L. SILVA, JAMES W.
| ASSEMBLY 68
LUCAS, PAUL TRAN, VAN
ASSEMBLY 69
SOLORIO, JOSE WILLIAMS, RYAN GENE
| ASSEMBLY 70
DE VORE, CHARLES S. GLOVER, MICHAEL G.
ASSEMBLY 71
LA CHANCE, IRENE SPITZER, TODD
| ASSEMBLY 72
CROSS, BRIAN LEE DUVALL, MIKE MAC MURRAY, JOHN P.
ASSEMBLY 73
FAVOR, ANDREW H.
| ASSEMBLY 74
FOLESCU, ROXANA GARRICK, MARTIN W.
ASSEMBLY 75
MEYER, SCOTT PLESCIA, GEORGE A. TEYSSIER, EDWARD M.
| ASSEMBLY 76
DENNEY, RALPH SALDANA, LORI
ASSEMBLY 77
ANDERSON, JOEL C. BELITZ, RICHARD G. LARKIN, CHRISTOPHER
| ASSEMBLY 78
GIBSON, GEOF C. HORTON, SHIRLEY SHERARD, MAXINE J.
ASSEMBLY 79
ROESCH, JEAN DR. SALAS, MARY H.
| ASSEMBLY 80
CLUTE, STEVE W. GARCIA, BONNIE